/****************************************************************************
*
* (C) Copyright H. Jelonneck, All Rights Reserved.
*
* This header file includes all public symbols published by ABC.
*
*****************************************************************************/

#ifndef _ABC_H_INCLUDED

#include <nwtypes.h>

#ifdef __cplusplus
extern "C" {
#endif

/*

   IMPORTANT NOTE FOR NETWARE 4.xx USERS:

   As described in the manual "ABC.DOC", ABC must be loaded in DOMAIN=OS
   when you run DOMAIN to protect your server memory. If you will use
   the following functions in your self written .NLM, it must also be
   loaded in ring 0 of server memory (DOMAIN=OS) to import the public
   symbols supplied by ABC.

   ------------------------------------------------------------------------

   BYTE ABCBroadcastMessage (char *User, char *Message)

   schedules one message for an immediate broadcast to ABC. This command
   uses the same syntax as described in the manual "ABC.DOC" in the
   chapters: "USER:" and "MESSAGE:".

   It supports all the features described there like multi user and
   multi groups in a multi server environment.

   The message text can include all the special characters that are
   described in the MESSAGE: chapter of the manual. The expanded message
   must not exceed 58 characters, but I recommend that you limit it to
   55 characters.

   ABCBroadcastMessage returns the following hex values:

        00 = broadcast text sucessfully scheduled.
        01 = Warning: broadcast text exceeds 55 characters after
                      expanding.
        02 = Error:   Previous broadcast text has been scheduled but not yet
                      sent by ABC. Wait until ABC has finished the previous
                      broadcast and call this function again. You can test if
                      ABC has finished the previous broadcast by calling this
                      function with empty strings (Both "User" and "Message"
                      must be set to ""). In this case it returns either 0 or
                      2.
        03 = Error:   broadcast text has a zero length or exceeds 58
                      characters after expanding.
        04 = Error:   broadcast text includes wrong %FN - parameters.
                      Please consult the manual for valid parameters
                      for this special message character.
        1x = Error:   "User" string has a zero length or exceeds 119
                      characters.

   All errors will suppress the schedule function. So, if you receive a
   return error, correct your parameters and call this function again.

   Example of a call:

   ReturnCode = ABCBroadcastMessage ("#supervisors,peter,MyServer/Mary",
                                     "Hello everyone its %ti");

*/

BYTE ABCBroadcastMessage (char *User, char *Message);

/*
   BYTE ABCDoCommand (char *CommandLines)

   schedules COMMAND: lines to the ABC COMMAND: processor for an immediate
   execution. It supports all the functions that are described in the chapter
   COMMAND: of the manual "ABC.DOC".

   The string "CommandLines" consist of a NULL terminated string. Every
   COMMAND: line in this string must be terminated by a CR (\r). Line feeds
   (\n) are not allowed.

   ABCDoCommand does no syntax check of any kind on the input string. So it is
   on you NOT to supply a COMMAND: string that contains invalid values in
   subcommands. If you do, unpredictable results may occur. It's also possible
   that the server will abend. So please be careful.

   ABCDoCommand return the following hex values:

        00 = Contents of CommandLines sucessfully scheduled.
        01 = Error:   ABC is unable to allocate memory for a local copy of
                      CommandLines. If you split your CommandLines to less
                      than 120 characters per call, ABC uses an internal
                      static buffer for its local copy, not using dynamic
                      memory.
        02 = Error:   Previous "CommandLines" contents have been scheduled but
                      not yet finished by ABC. Wait until ABC has finished the
                      previous CommandLines and call this function again. You
                      can test if ABC has finished its job by calling this
                      function with an empty string. In this case it returns
                      either 0 or 2.

   All errors will suppress the execution of the CommandLines. So, if you
   receive a return error, wait or shorten your call parameter and call this
   function again.

   Example of a call:

   ReturnCode = ABCDoCommand ("screen: monitor\r %keyevt%dly%-cr\r
                               IF: 0 0 - SKIP 4 LINES\r screen: console\r
                               load monitor\r %dly%dly%-cr\r screen: monitor\r");

   Look at "MONITOR.ABC" for a further description of the above example.

   ReturnCode = ABCDoCommand ("");

   This checks if the last ABCDoCommand has been finished.

*/

BYTE ABCDoCommand (char *CommandLines);

/*
   The following 3 functions set, reset, or xor one of the 64 flags of
   ABC. The input parameter can vary from 1 to 64. If the input value
   exceeds these limits, the functions return a TRUE and no flag is
   altered. When the parameter is inside the limits these functions
   return a FALSE and the specified flag will be changed.

*/

BYTE ABCSetFlag (BYTE FlagNo);

BYTE ABCResetFlag (BYTE FlagNo);

BYTE ABCXorFlag (BYTE FlagNo);

/*
   LONG ABCReadFlags (BYTE FlagsNo)

   returns either the low 32 or high 32 bits of the ABC Flags.
   The input parameter "FlagsNo" can be either 1 or 2. When 1
   is given then the low 32 bits (1-32) are returned, if a 2 is
   given then the high 32 bits (flags 33 - 64) are returned.

   Bit 0 represents flag 1 or 33, bit 1 the flag 2 or 34, ....
   bit 31 the flag 32 or 64.
*/

LONG ABCReadFlags (LONG *FlagsNo);

/*
   The variables ABCFlags [2] gives you direct access to the
   flag variables of ABC. ABCFlags [0] represents the flags
   32 to 1, ABCFlags [1] represents the flags 64 to 33.

*/

extern LONG ABCFlags [2];

/*
    LONG ABCGetVersion (void)

    returns the ABC version number as a LONG integer. The value is
    returned without the '.'. E.g: if currently ABC version 2.07 is
    loaded then "ABCGetVersion" returns a value of 207.
*/

LONG ABCGetVersion (void);

#ifdef __cplusplus
}
#endif

#define _ABC_H_INCLUDED
#endif  /* _ABC_H_INCLUDED  */

